@@ -4,7 +4,7 @@ import jwt
 import requests
 from functools import wraps
 from firebase_admin import firestore
-from flask import request, abort, json
+from flask import request, abort, json, jsonify
 from os import getenv
 import logging
 import base64
@@ -30,7 +30,7 @@ def authorize(scope):
             if scope in scopes:
                 return endpoint_func(*args, **kwargs)
             else:
-                return abort(403, "NOT ALLOWED")
+                return abort(403, jsonify({"error": f"Insufficient scopes. Required scope: {scope}"}))
         return decorated_function
     return decorator
 
@@ -60,7 +60,7 @@ def get_scopes(tenant_id=None):
                 return scopes
             else:
                 logger.error("Failed to retrieve roles. ROLES_HOST is not set.")
-                return abort(500, "INTERNAL SERVER ERROR")
+                return abort(500, jsonify({"error": "Something went wrong"}))
         else:
             if host:
                 roles = get_platform_roles(host)
@@ -71,8 +71,8 @@ def get_scopes(tenant_id=None):
                 return scopes
             else:
                 logger.error("Failed to retrieve roles. ROLES_HOST is not set.")
-                return abort(500, "INTERNAL SERVER ERROR")
-    return abort(403, "NOT ALLOWED")
+                return abort(500, jsonify({"error": "Something went wrong"}))
+    return abort(403, jsonify({"error": "Invalid token"}))
 
 
 def get_user_roles(host):
